# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .Progress import Progress
from .options.ProgressOptions import ProgressOptions
from .Output import Output
from .options.OutputOptions import OutputOptions
from .View import View
from .options.ViewOptions import ViewOptions
from .Content import Content
from .options.ContentOptions import ContentOptions


# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .VerifyActionResult import VerifyActionResult
from .ConsumeActionResult import ConsumeActionResult
from .AcquireActionResult import AcquireActionResult
from .options.TransactionResultOptions import TransactionResultOptions


class TransactionResult:
    transaction_id: str
    verify_results: Optional[List[VerifyActionResult]] = None
    consume_results: Optional[List[ConsumeActionResult]] = None
    acquire_results: Optional[List[AcquireActionResult]] = None

    def __init__(
        self,
        transaction_id: str,
        options: Optional[TransactionResultOptions] = TransactionResultOptions(),
    ):
        self.transaction_id = transaction_id
        self.verify_results = options.verify_results if options.verify_results else None
        self.consume_results = options.consume_results if options.consume_results else None
        self.acquire_results = options.acquire_results if options.acquire_results else None

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.transaction_id is not None:
            properties["transactionId"] = self.transaction_id
        if self.verify_results is not None:
            properties["verifyResults"] = [
                v.properties(
                )
                for v in self.verify_results
            ]
        if self.consume_results is not None:
            properties["consumeResults"] = [
                v.properties(
                )
                for v in self.consume_results
            ]
        if self.acquire_results is not None:
            properties["acquireResults"] = [
                v.properties(
                )
                for v in self.acquire_results
            ]

        return properties



# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *
from .DefaultGradeModel import DefaultGradeModel
from .GradeEntryModel import GradeEntryModel
from .AcquireActionRate import AcquireActionRate
from .options.GradeModelOptions import GradeModelOptions


class GradeModel:
    name: str
    experience_model_id: str
    grade_entries: List[GradeEntryModel]
    metadata: Optional[str] = None
    default_grades: Optional[List[DefaultGradeModel]] = None
    acquire_action_rates: Optional[List[AcquireActionRate]] = None

    def __init__(
        self,
        name: str,
        experience_model_id: str,
        grade_entries: List[GradeEntryModel],
        options: Optional[GradeModelOptions] = GradeModelOptions(),
    ):
        self.name = name
        self.experience_model_id = experience_model_id
        self.grade_entries = grade_entries
        self.metadata = options.metadata if options.metadata else None
        self.default_grades = options.default_grades if options.default_grades else None
        self.acquire_action_rates = options.acquire_action_rates if options.acquire_action_rates else None

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}

        if self.name is not None:
            properties["name"] = self.name
        if self.metadata is not None:
            properties["metadata"] = self.metadata
        if self.default_grades is not None:
            properties["defaultGrades"] = [
                v.properties(
                )
                for v in self.default_grades
            ]
        if self.experience_model_id is not None:
            properties["experienceModelId"] = self.experience_model_id
        if self.grade_entries is not None:
            properties["gradeEntries"] = [
                v.properties(
                )
                for v in self.grade_entries
            ]
        if self.acquire_action_rates is not None:
            properties["acquireActionRates"] = [
                v.properties(
                )
                for v in self.acquire_action_rates
            ]

        return properties
